# Chapter 3
# Hoteling T squared Depedent Sample
# Install R package and load library of functions

install.packages("ICSNP")
install.packages("mvtnorm")
library(ICSNP) 
library (mvtnorm)

# Enter data for two dependent variables (Pre and Post) and two groups (Boy and Girl)

PreBoy  = c(12,16,18,12,10)
PostBoy = c(14,16,18,10,12)
PreGirl = c(5,2,7,4,15)
PostGirl = c(8,2,16,10,14)
mydata = data.frame(PreBoy,PostBoy,PreGirl,PostGirl)
attach(mydata)
mydata

# Compute descriptive statistics on dependent variables for each group

mean(PreBoy);sd(PreBoy)
mean(PostBoy);sd(PostBoy)
mean(PreGirl);sd(PreGirl)
mean(PostGirl);sd(PostGirl)

#  Approach 1 - Difference Scores

diffBoy = PostBoy - PreBoy
diffGirl = PostGirl - PreGirl

mean(diffBoy);sd(diffBoy)
mean(diffGirl);sd(diffGirl)

# graph group mean differences

install.packages("psych")
library(psych)

# Place difference scores in data frame
# Print out difference scores

YDiff = data.frame(diffBoy,diffGirl)
YDiff

error.bars(YDiff,bar=FALSE,ylab="Mean Difference",xlab="Groups",ylim=c(-10,10),eyes=FALSE)

# Compute Hotelling T-square on difference scores for Boys

muH0 = c(0)
HotellingsT2(diffBoy, mu=muH0)

# Compute Hotelling T-square on difference scores for Girls

muH0 = c(0)
HotellingsT2(diffGirl, mu=muH0)

# Approach 2 - Calculate difference scores from complete data set

g = 2  # number of groups
N = 5  # number of subjects per group

Group = matrix(rep(1:g, each=N))
Pre=c(PreBoy,PreGirl)
Post=c(PostBoy,PostGirl)
YDiff   = data.frame(Pre,Post,Group)
names(YDiff) = c("Pre","Post","Group")
factor(Group) 
YDiff

# Descriptive statistics

mean(Pre)
mean(Post)

# Create data matrix of difference scores for all students
# Print out difference scores
# Compute average difference score

Diff = cbind(Post-Pre)
Diff
mean(Diff)

# Compute Hotelling T-square on difference scores for all students

muH0 = c(0)
HotellingsT2(Diff, mu=muH0)

#####################################################
Alternative program code
######################################################

N = 5  # number of subjects
P = 2  # number of dependent variables

Ydf   = data.frame(id=factor(rep(1:N,times=P)),
                   Y1=c(Y1g1,Y1g2),
                   Y2=c(Y2g1,Y2g2),
                   IV=factor(rep(1:P, each=N),labels = c("g1","g2")))

dfDiff = aggregate(cbind(Y1,Y2) ~ id,data = Ydf,FUN = diff)
YDiff2 = data.matrix(dfDiff[,-1])
YDiff2

muH0 = c(0, 0)
HotellingsT2(YDiff2, mu=muH0)



