# Chapter 3
# R Code Hotelling T-squared Two Independent Groups
# Install R package and load library of functions

install.packages("ICSNP")
install.packages("mvtnorm")
library(ICSNP) 
library (mvtnorm)

# Use data set from James Steven Book (5th Edition) P. 148
# with the independent variables Rogerian vs Adlerian
# Assign data to vectors

 roger = matrix(c(1,3,2,3,7,2),3,2)
 adler = matrix(c(4,6,6,5,5,4,6,8,8,10,10,6),6,2)

# Print out the two dependent variable data vectors

 roger
 adler

# Create a group membership vector and declare as fixed factor

 grp = matrix(c(1,1,1,2,2,2,2,2,2),9,1)
 factor(grp)
 grp

# Combine the two dependent variable matrices

Y12 = data.frame(rbind(roger,adler))
names(Y12) = c("Y1","Y2")
attach(Y12)
Y12

# Eliminate the scientific notation

 options(scipen=999)

# Print out correlation matrix, means and standard deviations

cor(Y12) 
mean(Y1); sd(Y1)
mean(Y2); sd(Y2)

# Graph dependent variable means

install.packages("gplots")
library(gplots)

group = data.frame(grp)
Y123 = data.frame(group,Y12)

par(mfrow = c(2, 1))

plotmeans(Y1 ~ grp,data=Y123,ylim=c(0,10),xlab="Groups",legends=c("Rogerian","Adlerian"),main = "Counseling Effectiveness",connect=FALSE,mean.labels=TRUE,col=NULL,p=1.0)

plotmeans(Y2 ~ grp,data=Y123,ylim=c(0,10),xlab="Groups",legends=c("Rogerian","Adlerian"),main = "Counseling Satisfaction",connect=FALSE,mean.labels=TRUE,col=NULL,p=1.0)

# Bartlett test of equal covariance matrices
# Compute sample covariance matrices for each group
     p = 2
    n1 = 3
    n2 = 6
    s1 = var(roger)
    s2 = var(adler)

#  Compute the pooled estimate of covariance matrix

    s = ((n1-1)*s1+(n2-1)*s2)/(n1+n2-2) 

# Compute eigenvalues for each covariance matrix

    es = eigen(s)
    es1= eigen(s1)
    es2 = eigen(s2)

    M = (n1+n2-2)*log(prod(es$values))
    M = M-(n1-1)*log(prod(es1$values)) - (n2-1)*log(prod(es2$values))
    CI = 1-((2*p*p+3*p-1)/(6*(p+1)))*((1/(n1-1)) + (1/(n2-1))-(1/(n1+n2-2)))
    B = CI*M
    df = p*(p+1)/2
    pval = 1-pchisq(B,df)

    cat("Bartlett Test = ",B," df = ",df," p-value = ",pval,fill=T)


# HotellingsT2 function

??HotellingsT2

# Run Hotelling T statistics

 Y12 = rbind(roger,adler)
 HotellingsT2(Y12 ~ grp)

######################################################## 
# Optional robust Hotelling T2 with vector means output
########################################################

install.packages("rrcov")
library(rrcov)
T2.test(Y12 ~ grp)

# Alternative method using just the two matrices

HotellingsT2(roger,  adler, mu=NULL, test="f")

#  Compute F test for Hotelling T-squared value 
#  Enter sample sizes, number of dependent variables, and Hotelling T2 value

n1 = 3
n2 = 6
p = 2
T = 3

# Compute degrees of freedom for numerator and denominator

df1 = p
df2 = n1 + n2 - p -1

# Compute F value and p-value

Fval =  (df2/df1) * T
pval =  round(1-pf(Fval,df1,df2),digits=3)

# print out T, F, df1, df2, and p-value

cat("T = ",T,"F-value =",Fval,"df1 =",df1,"df2 =",df2," p-value=",pval,fill=FALSE,"\n")
